<img src="ahsoka_logo.png">

# Ahsoka

Developing a pipeline for JWST near-IR transiting exoplanet data


## Installation

The latest version of Ahsoka can be installed directly with pip:

`pip install ahsoka`

To install a development version:

    Clone the repository:  
    `git clone https://github.com/Witchblade101/ahsoka`
        or
    `git@github.com:Witchblade101/ahsoka.git`

    Install ahsoka:  
    `cd ahsoka`  
    `pip install .`

    Install in Develop Mode
    `pip install -e .`